@@ -515,7 +515,7 @@ class Command(BaseCommand):
         }])
         ws_settings.favicon = mocker.file(mocker.IMG_ICON_SPACE)
         ws_settings.language = 'fr'
-        ws_settings.collect_text = "En poursuivant votre navigation sur ce site, vous acceptez nos CGU ainsi que notre Politique de confidentialité"
+        ws_settings.collect_text = "<p>En poursuivant votre navigation sur ce site, vous acceptez nos CGU ainsi que notre Politique de confidentialité</p>"
         ws_settings.social_share_text = """
         <h2>Suivez-nous!</h2>
         <hr>
