@@ -1,44 +1,18 @@
 from wagtail.contrib.settings.models import register_setting
 from wagtail.snippets.models import register_snippet
-from wagtail.documents.models import Document, AbstractDocument
-from django.db import models
 
 from webspace.loader import is_model_registered
 
 __all__ = []
 
 
+from .document.abstract import AMyDocument
+
 if not is_model_registered('cms', 'MyDocument'):
-    class MyDocument(AbstractDocument):
-        #  Dimensions for SVG
+    class MyDocument(AMyDocument):
+        pass
 
-        width = models.IntegerField(
-            default=None,
-            blank=True,
-            null=True,
-            help_text="for SVG"
-        )
-        height = models.IntegerField(
-            default=None,
-            blank=True,
-            null=True,
-            help_text="for SVG"
-        )
-
-        admin_form_fields = Document.admin_form_fields + (
-            'width',
-            'height'
-        )
-
-        def get_size(self):
-            return '500x500'
-
-        class Meta:
-            verbose_name = "MyDocument"
-            app_label = 'cms'
-
-
-__all__.append('MyDocument')
+    __all__.append('MyDocument')
 
 
 # Snippets
@@ -146,7 +120,6 @@ if not is_model_registered('cms', 'WebspaceSettings'):
 
 
 if not is_model_registered('cms', 'Founders'):
-    @register_setting
     class Founders(AFounders):
         pass
 
