@@ -10,28 +10,28 @@ from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
 from django.http import Http404
 from django.template.response import TemplateResponse
 
-from wagtail.documents.models import Document
 from wagtail.admin.edit_handlers import FieldPanel
-from wagtail.documents.edit_handlers import DocumentChooserPanel
 from wagtail.core.url_routing import RouteResult
 from wagtail.core import fields
 from wagtail.core.models import Page
 from wagtail.admin.edit_handlers import StreamFieldPanel
 from wagtail.core.fields import StreamField
 from wagtail.core import blocks
+from wagtail.images.blocks import ImageChooserBlock
+from wagtail.documents.blocks import DocumentChooserBlock
 
 from modelcluster.fields import ParentalKey
 from modelcluster.tags import ClusterTaggableManager
 from taggit.models import Tag, TaggedItemBase
 
-from ..blocks.entries.text import Text
-from ..bakery.models import BuildableWagtailBakeryModel
-from .. import constants
-from ..amp.mixins import AmpMixin
+from webspace.cms.bakery.abstract import WagtailPageBakeryModel
+from webspace.cms import constants
+from webspace.cms.amp.mixins import AmpMixin
 
-from ...loader import get_model
+from webspace.loader import get_model, get_class
 
 GenericPage = get_model('cms', 'GenericPage')
+TextEntry = get_class('cms.blocks.entries', 'TextEntry')
 
 
 class ABlogPageTag(TaggedItemBase):
@@ -42,7 +42,7 @@ class ABlogPageTag(TaggedItemBase):
         abstract = True
 
 
-class ABlogPage(AmpMixin, BuildableWagtailBakeryModel, GenericPage):
+class ABlogPage(AmpMixin, WagtailPageBakeryModel, GenericPage):
     template = '%s/blog_page.html' % constants.PAGES_TEMPLATES_PATH
     author = models.ForeignKey(
         settings.WAGTAIL_BLOG_AUTHOR_PAGE,
@@ -50,28 +50,18 @@ class ABlogPage(AmpMixin, BuildableWagtailBakeryModel, GenericPage):
         null=True,
         on_delete=models.SET_NULL,
     )
-    svg_cover = models.ForeignKey(
-        Document,
-        null=True,
-        blank=True,
-        on_delete=models.SET_NULL,
-        related_name='+',
-        help_text='Dimension : 1920x1080'
-    )
-    svg_bg_desktop = models.ForeignKey(
-        Document,
-        null=True,
-        blank=True,
-        on_delete=models.SET_NULL,
-        related_name='+',
-    )
-    svg_bg_mobile = models.ForeignKey(
-        Document,
-        null=True,
-        blank=True,
-        on_delete=models.SET_NULL,
-        related_name='+',
-    )
+    cover = StreamField([
+        ('image', ImageChooserBlock()),
+        ('svg', DocumentChooserBlock()),
+    ], blank=True)
+    bg_desktop = StreamField([
+        ('image', ImageChooserBlock()),
+        ('svg', DocumentChooserBlock()),
+    ], blank=True)
+    bg_mobile = StreamField([
+        ('image', ImageChooserBlock()),
+        ('svg', DocumentChooserBlock()),
+    ], blank=True)
     tags = ClusterTaggableManager(through='BlogPageTag', blank=True)
     date = models.DateTimeField("Date publication + tri", default=date.today)
     date_updated = models.DateTimeField("Date mise à jour", default=None, null=True, blank=True)
@@ -86,14 +76,14 @@ class ABlogPage(AmpMixin, BuildableWagtailBakeryModel, GenericPage):
         StreamFieldPanel('schemas'),
     ]
     content_panels = [
+                         StreamFieldPanel('bg_desktop'),
+                         StreamFieldPanel('bg_mobile'),
+                         StreamFieldPanel('cover'),
                          FieldPanel('author'),
                          FieldPanel('date'),
                          FieldPanel('date_updated'),
                          FieldPanel('tags'),
-                         DocumentChooserPanel('svg_cover'),
                          FieldPanel('intro'),
-                         DocumentChooserPanel('svg_bg_desktop'),
-                         DocumentChooserPanel('svg_bg_mobile'),
                          FieldPanel('h1'),
                          FieldPanel('intro_page'),
                          StreamFieldPanel('related_blogs'),
@@ -112,7 +102,7 @@ class ABlogPage(AmpMixin, BuildableWagtailBakeryModel, GenericPage):
         rgx = re.compile(r'<.*?>')
         words = ""
         for block in self.body:
-            if isinstance(block.block, Text):
+            if isinstance(block.block, TextEntry):
                 text = block.value['text']['value'].source
                 words += " " + rgx.sub('', text)
         return readtime.of_text(words)
@@ -122,58 +112,56 @@ class ABlogPage(AmpMixin, BuildableWagtailBakeryModel, GenericPage):
 
     def get_context(self, request, *args, **kwargs):
         context = super(ABlogPage, self).get_context(request)
-        html = render(
-            request,
-            self.get_template(request, *args, **kwargs),
-            context
-        )
-        tree = etree.HTML(html.content)
-        summary = []
-        for node in tree.xpath('//h2|//h3|//h4|//h5'):
-            if node.attrib.get('id'):
-                if node.tag == 'h2':
-                    summary.append({
-                        'content': node.text,
-                        'link': node.attrib.get('id'),
-                        'h3': []
-                    })
-                if node.tag == 'h3':
-                    summary[-1]['h3'].append({
-                        'content': node.text,
-                        'link': node.attrib.get('id'),
-                        'h4': []
-                    })
-                if node.tag == 'h4':
-                    summary[-1]['h3'][-1]['h4'].append({
-                        'content': node.text,
-                        'link': node.attrib.get('id'),
-                    })
-        context['summary'] = summary
+        try:
+            html = render(
+                request,
+                self.get_template(request, *args, **kwargs),
+                context
+            )
+            tree = etree.HTML(html.content)
+            summary = []
+            for node in tree.xpath('//h2|//h3|//h4|//h5'):
+                if node.attrib.get('id'):
+                    if node.tag == 'h2':
+                        summary.append({
+                            'content': node.text,
+                            'link': node.attrib.get('id'),
+                            'h3': []
+                        })
+                    if node.tag == 'h3':
+                        summary[-1]['h3'].append({
+                            'content': node.text,
+                            'link': node.attrib.get('id'),
+                            'h4': []
+                        })
+                    if node.tag == 'h4':
+                        summary[-1]['h3'][-1]['h4'].append({
+                            'content': node.text,
+                            'link': node.attrib.get('id'),
+                        })
+            context['summary'] = summary
+        except Exception:
+            context['summary'] = None
         return context
 
 
-class ABlogIndexPage(AmpMixin, BuildableWagtailBakeryModel, GenericPage):
+class ABlogIndexPage(AmpMixin, WagtailPageBakeryModel, GenericPage):
+    subpage_types = ['BlogPage']
     template = '%s/blog_index_page.html' % constants.PAGES_TEMPLATES_PATH
-    svg_bg_desktop = models.ForeignKey(
-        Document,
-        null=True,
-        blank=True,
-        on_delete=models.SET_NULL,
-        related_name='+',
-    )
-    svg_bg_mobile = models.ForeignKey(
-        Document,
-        null=True,
-        blank=True,
-        on_delete=models.SET_NULL,
-        related_name='+',
-    )
+    bg_desktop = StreamField([
+        ('image', ImageChooserBlock()),
+        ('svg', DocumentChooserBlock()),
+    ], blank=True)
+    bg_mobile = StreamField([
+        ('image', ImageChooserBlock()),
+        ('svg', DocumentChooserBlock()),
+    ], blank=True)
     h1 = models.CharField(default='', max_length=200, blank=True)
     first_text = fields.RichTextField(default='', blank=True, features=settings.RICH_TEXT_FEATURES)
 
     content_panels = [
-                         DocumentChooserPanel('svg_bg_desktop'),
-                         DocumentChooserPanel('svg_bg_mobile'),
+                         StreamFieldPanel('bg_desktop'),
+                         StreamFieldPanel('bg_mobile'),
                          FieldPanel('h1'),
                          FieldPanel('first_text'),
                      ] + Page.content_panels
@@ -199,14 +187,15 @@ class ABlogIndexPage(AmpMixin, BuildableWagtailBakeryModel, GenericPage):
 
     @property
     def blogs(self):
-        blogs = ABlogPage.objects.live().descendant_of(self)
+        BlogPage = get_model('cms', 'BlogPage')
+        blogs = BlogPage.objects.live().descendant_of(self)
         blogs = blogs.order_by('-date')
         return blogs
 
     def get_context(self, request, tag=None):
         blogs = self.blogs
         if tag:
-            blogs = blogs.filter(tags__slug=tag)
+            blogs = blogs.filter(tags__slug=tag.slug)
         page = request.GET.get('page')
         paginator = Paginator(blogs,
                               getattr(settings, 'WAGTAIL_BLOG_POSTS_PER_PAGE', 10))
@@ -233,7 +222,7 @@ class ABlogIndexPage(AmpMixin, BuildableWagtailBakeryModel, GenericPage):
             return TemplateResponse(
                 request,
                 self.get_template(request),
-                self.get_context(request)
+                self.get_context(request, kwargs['tag'])
             )
         else:
             return self.render_baked_file(
